yakumo.nova.v2.agent.Manager

Package yakumo :: Package nova :: Package v2 :: Module agent :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for agents in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for agents in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.agent.Resource |
create(self, architecture=`'``__UNDEF__``'`, hypervisor=`'``__UNDEF__``'`, os=`'``__UNDEF__``'`, url=`'``__UNDEF__``'`, version=`'``__UNDEF__``'`) Register an agent | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``agent_id``'``,` <yakumo.mapper.NoopClass o`...``
| _json_resource_key = ``'``agent``'``
| _json_resources_key = ``'``agents``'``
| _url_resource_path = ``'``/os-agents``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, architecture=`'``__UNDEF__``'`, hypervisor=`'``__UNDEF__``'`, os=`'``__UNDEF__``'`, url=`'``__UNDEF__``'`, version=`'``__UNDEF__``'`) | source code
Register an agent Parameters: `architecture` (str) - Architecture `hypervisor` (str) - Hypervisor `os` (str) - Operating System `url` (str) - URL `version` (str) - Version Returns: yakumo.nova.v2.agent.Resource Registered agent Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id',
        'agent_id',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('architecture',
        'architecture',
        <yakumo.mapper.NoopClass object at 0x7f133076f290>),
       ('hypervisor',
        'hypervisor',
      ...